from    asteriskutils.setting import lang_pack
def lang(txt:str) -> str:
    '''
    翻译函数
    Args
        txt(str):需要翻译的文本
    Returns
        str:翻译后的文本
    '''
    if lang_pack.get(txt):
        return lang_pack[txt]
    else:
        return txt